psychopy_ext.fmri.Preproc.__init__ — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.Preproc.__init__

`Preproc.` `__init__`(paths, info=None, rp=None)

  Generates batch scripts from SPM preprocessing.

  Note

  Presently, only batch scripts for statistical analyses in SPM are available.

  Args: | paths (dict of str:str pairs) A dictionary of paths where data is stored. Expected to have at least the following keys: ‘fmri_root’ for moving the original realignment parameter (prefix rp) file ‘data_behav’ - where to find behavioral data with condition labels (passed`condcol` variable), onsets, and durations ‘data_fmri’ - where to find fMRI functional data ‘rec’ (for ROIs from surface reconstruction in Caret or so) ‘data_rois’ (for storing the extracted signals in these ROIs)